PluginRunResult class final
Outcome of launching a plugin command.
Constructors
- PluginRunResult({required bool success, required String message, int? exitCode})
-
Creates a run outcome with
successandmessage.const
Properties
- exitCode → int?
-
Exit code of an
inheritcommand;nullfor detached launches and launch failures.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable status or error message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → bool
-
Whether the command launched (detached) or exited with
0(inherit).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited